Class: Google::Cloud::ConfigDelivery::V1::ClusterInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/configdelivery/v1/config_delivery.rb

Overview

ClusterInfo represents status of a resource bundle rollout for a cluster.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#current::Google::Cloud::ConfigDelivery::V1::ResourceBundleDeploymentInfo (readonly)

Returns Output only. Current state of the resource bundle.

Returns:



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 443

class ClusterInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the rollout for the cluster.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Waiting state.
    WAITING = 1

    # In progress state.
    IN_PROGRESS = 2

    # Stalled state.
    STALLED = 3

    # Completed state.
    COMPLETED = 4

    # Aborted state.
    ABORTED = 5

    # Cancelled state.
    CANCELLED = 6

    # Error state.
    ERROR = 7

    # Unchanged state.
    UNCHANGED = 8

    # Skipped state.
    SKIPPED = 9
  end
end

#desired::Google::Cloud::ConfigDelivery::V1::ResourceBundleDeploymentInfo (readonly)

Returns Output only. Desired state for the resource bundle.

Returns:



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 443

class ClusterInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the rollout for the cluster.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Waiting state.
    WAITING = 1

    # In progress state.
    IN_PROGRESS = 2

    # Stalled state.
    STALLED = 3

    # Completed state.
    COMPLETED = 4

    # Aborted state.
    ABORTED = 5

    # Cancelled state.
    CANCELLED = 6

    # Error state.
    ERROR = 7

    # Unchanged state.
    UNCHANGED = 8

    # Skipped state.
    SKIPPED = 9
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when reconciliation ends.

Returns:



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 443

class ClusterInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the rollout for the cluster.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Waiting state.
    WAITING = 1

    # In progress state.
    IN_PROGRESS = 2

    # Stalled state.
    STALLED = 3

    # Completed state.
    COMPLETED = 4

    # Aborted state.
    ABORTED = 5

    # Cancelled state.
    CANCELLED = 6

    # Error state.
    ERROR = 7

    # Unchanged state.
    UNCHANGED = 8

    # Skipped state.
    SKIPPED = 9
  end
end

#initial::Google::Cloud::ConfigDelivery::V1::ResourceBundleDeploymentInfo (readonly)

Returns Output only. Initial state of the resource bundle prior to the deployment.

Returns:



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 443

class ClusterInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the rollout for the cluster.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Waiting state.
    WAITING = 1

    # In progress state.
    IN_PROGRESS = 2

    # Stalled state.
    STALLED = 3

    # Completed state.
    COMPLETED = 4

    # Aborted state.
    ABORTED = 5

    # Cancelled state.
    CANCELLED = 6

    # Error state.
    ERROR = 7

    # Unchanged state.
    UNCHANGED = 8

    # Skipped state.
    SKIPPED = 9
  end
end

#membership::String (readonly)

Returns Output only. gkehub membership of target cluster.

Returns:

  • (::String)

    Output only. gkehub membership of target cluster



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 443

class ClusterInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the rollout for the cluster.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Waiting state.
    WAITING = 1

    # In progress state.
    IN_PROGRESS = 2

    # Stalled state.
    STALLED = 3

    # Completed state.
    COMPLETED = 4

    # Aborted state.
    ABORTED = 5

    # Cancelled state.
    CANCELLED = 6

    # Error state.
    ERROR = 7

    # Unchanged state.
    UNCHANGED = 8

    # Skipped state.
    SKIPPED = 9
  end
end

#messages::Array<::String> (readonly)

Returns Output only. Unordered list. Messages convey additional information related to the deployment.

Returns:

  • (::Array<::String>)

    Output only. Unordered list. Messages convey additional information related to the deployment.



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 443

class ClusterInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the rollout for the cluster.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Waiting state.
    WAITING = 1

    # In progress state.
    IN_PROGRESS = 2

    # Stalled state.
    STALLED = 3

    # Completed state.
    COMPLETED = 4

    # Aborted state.
    ABORTED = 5

    # Cancelled state.
    CANCELLED = 6

    # Error state.
    ERROR = 7

    # Unchanged state.
    UNCHANGED = 8

    # Skipped state.
    SKIPPED = 9
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Timestamp when reconciliation starts.

Returns:



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 443

class ClusterInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the rollout for the cluster.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Waiting state.
    WAITING = 1

    # In progress state.
    IN_PROGRESS = 2

    # Stalled state.
    STALLED = 3

    # Completed state.
    COMPLETED = 4

    # Aborted state.
    ABORTED = 5

    # Cancelled state.
    CANCELLED = 6

    # Error state.
    ERROR = 7

    # Unchanged state.
    UNCHANGED = 8

    # Skipped state.
    SKIPPED = 9
  end
end

#state::Google::Cloud::ConfigDelivery::V1::ClusterInfo::State (readonly)

Returns Output only. State of the rollout for the cluster.

Returns:



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 443

class ClusterInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the rollout for the cluster.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Waiting state.
    WAITING = 1

    # In progress state.
    IN_PROGRESS = 2

    # Stalled state.
    STALLED = 3

    # Completed state.
    COMPLETED = 4

    # Aborted state.
    ABORTED = 5

    # Cancelled state.
    CANCELLED = 6

    # Error state.
    ERROR = 7

    # Unchanged state.
    UNCHANGED = 8

    # Skipped state.
    SKIPPED = 9
  end
end