Class: Google::Cloud::ConfigDelivery::V1::CreateFleetPackageRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::CreateFleetPackageRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
Message for creating a FleetPackage
Instance Attribute Summary collapse
-
#fleet_package ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage
Required.
-
#fleet_package_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#fleet_package ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage
Returns Required. The resource being created.
721 722 723 724 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 721 class CreateFleetPackageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#fleet_package_id ⇒ ::String
Returns Required. Id of the requesting object If auto-generating Id server-side, remove this field and fleet_package_id from the method_signature of Create RPC.
721 722 723 724 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 721 class CreateFleetPackageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Value for parent.
721 722 723 724 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 721 class CreateFleetPackageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
721 722 723 724 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 721 class CreateFleetPackageRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |