Class: Google::Cloud::ConfigDelivery::V1::FleetPackage
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::FleetPackage
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
A FleetPackage resource in the Config Delivery API.
A FleetPackage defines a package through which kubernetes
configuration is deployed to a fleet of kubernetes clusters.
Defined Under Namespace
Modules: State Classes: CloudBuildRepository, LabelsEntry, ResourceBundleSelector, ResourceBundleTag, Target, VariantSelector
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#deletion_propagation_policy ⇒ ::Google::Cloud::ConfigDelivery::V1::DeletionPropagationPolicy
Optional.
-
#info ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackageInfo
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#resource_bundle_selector ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleSelector
Required.
-
#rollout_strategy ⇒ ::Google::Cloud::ConfigDelivery::V1::RolloutStrategy
Optional.
-
#state ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::State
Optional.
-
#target ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::Target
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#variant_selector ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::VariantSelector
Required.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time at which the FleetPackage was created.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#deletion_propagation_policy ⇒ ::Google::Cloud::ConfigDelivery::V1::DeletionPropagationPolicy
Returns Optional. Information around how to handle kubernetes resources at the
target clusters when the FleetPackage is deleted.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#info ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackageInfo (readonly)
Returns Output only. Information containing the rollout status of the
FleetPackage across all the target clusters.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels are attributes that can be set and used by both the user and by Config Delivery. Labels must meet the following constraints:
- Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes.
- All characters must use UTF-8 encoding, and international characters are allowed.
- Keys must start with a lowercase letter or international character.
- Each resource is limited to a maximum of 64 labels.
Both keys and values are additionally constrained to be <= 128 bytes.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#name ⇒ ::String
Returns Identifier. Name of the FleetPackage. Format is
projects/{project}/locations/{location}/fleetPackages/{fleetPackage}.
The fleetPackage component must match
[a-z][a-z0-9\-]{0,62}.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#resource_bundle_selector ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleSelector
Returns Required. Information specifying the source of kubernetes configuration to deploy.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#rollout_strategy ⇒ ::Google::Cloud::ConfigDelivery::V1::RolloutStrategy
Returns Optional. The strategy to use to deploy kubernetes configuration to clusters.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#state ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::State
Returns Optional. The desired state of the fleet package.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#target ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::Target
Returns Optional. Configuration to select target clusters to deploy kubernetes configuration to.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Most recent time at which the FleetPackage was updated.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |
#variant_selector ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::VariantSelector
Returns Required. Information specifying how to map a ResourceBundle variant to a
target cluster.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 250 class FleetPackage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information specifying the source of kubernetes configuration to deploy. # @!attribute [rw] resource_bundle # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag] # Information specifying `ResourceBundle`. # # Note: The following fields are mutually exclusive: `resource_bundle`, `cloud_build_repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] cloud_build_repository # @return [::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository] # Information specifying `CloudBuildRepository`. # # Note: The following fields are mutually exclusive: `cloud_build_repository`, `resource_bundle`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ResourceBundleTag contains the information to refer to a release for a # `ResourceBundle`. # @!attribute [rw] name # @return [::String] # Required. Name of the `ResourceBundle`. # Format is projects/\\{p}/locations/\\{l}/resourceBundles/\\{r}. # @!attribute [rw] tag # @return [::String] # Required. Tag refers to a version of the release in a `ResourceBundle`. # This is a Git tag in the semantic version format `vX.Y.Z`. class ResourceBundleTag include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # CloudBuildRepository contains information about fetching Kubernetes # configuration from a `CloudBuildRepository`. # @!attribute [rw] variants_pattern # @return [::String] # Optional. variants_pattern is a glob pattern that will be used to find # variants in the repository. Examples: `variants/*.yaml`, `us-*` # @!attribute [rw] name # @return [::String] # Required. Name of the cloud build repository. # Format is projects/\\{p}/locations/\\{l}/connections/\\{c}/repositories/\\{r}. # @!attribute [rw] path # @return [::String] # Optional. path to the directory or file within the repository that # contains the kubernetes configuration. If unspecified, path is assumed to # the top level root directory of the repository. # @!attribute [rw] tag # @return [::String] # Required. git tag of the underlying git repository. # The git tag must be in the semantic version format `vX.Y.Z`. # @!attribute [rw] service_account # @return [::String] # Required. Google service account to use in CloudBuild triggers to fetch # and store kubernetes configuration. class CloudBuildRepository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The target defines different ways to target set of kubernetes clusters. # @!attribute [rw] fleet # @return [::Google::Cloud::ConfigDelivery::V1::Fleet] # The GKE fleet information. class Target include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # VariantSelector contains information for selecting a variant in # `ResourceBundle` to deploy to a target cluster. # @!attribute [rw] variant_name_template # @return [::String] # Required. variant_name_template is a template that can refer to # variables containing cluster membership metadata such as location, # name, and labels to generate the name of the variant for a target # cluster. The variable syntax is similar to the unix shell variables. # # Available variables are `${membership.name}`, `${membership.location}`, # `${membership.project}` and `${membership.labels['label_name']}`. # # If you want to deploy a specific variant, say "default" to all the # clusters, you can use "default" (string without any variables) as # the variant_name_template. class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State indicates the desired state for the fleet package. # Unspecified value is equivalent to `ACTIVE`. If state is set to # `SUSPENDED`, active rollout (if any) will continue but no new rollouts will # be scheduled. module State # Unspecified state. STATE_UNSPECIFIED = 0 # `FleetPackage` is intended to be active. ACTIVE = 1 # `FleetPackage` is intended to be suspended. SUSPENDED = 2 end end |