Class: Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/configdelivery/v1/config_delivery.rb

Overview

CloudBuildRepository contains information about fetching Kubernetes configuration from a CloudBuildRepository.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Name of the cloud build repository. Format is projects/{p}/locations/{l}/connections/{c}/repositories/{r}.

Returns:

  • (::String)

    Required. Name of the cloud build repository. Format is projects/{p}/locations/{l}/connections/{c}/repositories/{r}.



308
309
310
311
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 308

class CloudBuildRepository
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path::String

Returns Optional. path to the directory or file within the repository that contains the kubernetes configuration. If unspecified, path is assumed to the top level root directory of the repository.

Returns:

  • (::String)

    Optional. path to the directory or file within the repository that contains the kubernetes configuration. If unspecified, path is assumed to the top level root directory of the repository.



308
309
310
311
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 308

class CloudBuildRepository
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#service_account::String

Returns Required. Google service account to use in CloudBuild triggers to fetch and store kubernetes configuration.

Returns:

  • (::String)

    Required. Google service account to use in CloudBuild triggers to fetch and store kubernetes configuration.



308
309
310
311
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 308

class CloudBuildRepository
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tag::String

Returns Required. git tag of the underlying git repository. The git tag must be in the semantic version format vX.Y.Z.

Returns:

  • (::String)

    Required. git tag of the underlying git repository. The git tag must be in the semantic version format vX.Y.Z.



308
309
310
311
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 308

class CloudBuildRepository
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#variants_pattern::String

Returns Optional. variants_pattern is a glob pattern that will be used to find variants in the repository. Examples: variants/*.yaml, us-*.

Returns:

  • (::String)

    Optional. variants_pattern is a glob pattern that will be used to find variants in the repository. Examples: variants/*.yaml, us-*



308
309
310
311
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 308

class CloudBuildRepository
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end