Class: Google::Cloud::ConfigDelivery::V1::ResourceBundleDeploymentInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/configdelivery/v1/config_delivery.rb

Overview

ResourceBundleDeploymentInfo represents the status of a resource bundle deployment.

Defined Under Namespace

Modules: SyncState

Instance Attribute Summary collapse

Instance Attribute Details

#messages::Array<::String> (readonly)

Returns Output only. Unordered list. Messages contains information related to the ResourceBundle deployment. For example, in case of an error, indicate the reason for the error. In case of a pending deployment, reason for why the deployment of new release is pending.

Returns:

  • (::Array<::String>)

    Output only. Unordered list. Messages contains information related to the ResourceBundle deployment. For example, in case of an error, indicate the reason for the error. In case of a pending deployment, reason for why the deployment of new release is pending.



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 501

class ResourceBundleDeploymentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Synchronization state of the resource bundle deployment.
  module SyncState
    # Unspecified state.
    SYNC_STATE_UNSPECIFIED = 0

    # Reconciling state.
    RECONCILING = 1

    # Stalled state.
    STALLED = 2

    # Synced state.
    SYNCED = 3

    # Pending state.
    PENDING = 4

    # Error state.
    ERROR = 5

    # Deletion pending state.
    DELETION_PENDING = 6

    # Deleting state.
    DELETING = 7

    # Deleted state.
    DELETED = 8
  end
end

#release::String (readonly)

Returns Output only. Refers to a ResourceBundle release.

Returns:

  • (::String)

    Output only. Refers to a ResourceBundle release.



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 501

class ResourceBundleDeploymentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Synchronization state of the resource bundle deployment.
  module SyncState
    # Unspecified state.
    SYNC_STATE_UNSPECIFIED = 0

    # Reconciling state.
    RECONCILING = 1

    # Stalled state.
    STALLED = 2

    # Synced state.
    SYNCED = 3

    # Pending state.
    PENDING = 4

    # Error state.
    ERROR = 5

    # Deletion pending state.
    DELETION_PENDING = 6

    # Deleting state.
    DELETING = 7

    # Deleted state.
    DELETED = 8
  end
end

#sync_state::Google::Cloud::ConfigDelivery::V1::ResourceBundleDeploymentInfo::SyncState (readonly)

Returns Output only. Synchronization state of the ResourceBundle deployment.

Returns:



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 501

class ResourceBundleDeploymentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Synchronization state of the resource bundle deployment.
  module SyncState
    # Unspecified state.
    SYNC_STATE_UNSPECIFIED = 0

    # Reconciling state.
    RECONCILING = 1

    # Stalled state.
    STALLED = 2

    # Synced state.
    SYNCED = 3

    # Pending state.
    PENDING = 4

    # Error state.
    ERROR = 5

    # Deletion pending state.
    DELETION_PENDING = 6

    # Deleting state.
    DELETING = 7

    # Deleted state.
    DELETED = 8
  end
end

#variant::String (readonly)

Returns Output only. Refers to a variant in a ResourceBundle release.

Returns:

  • (::String)

    Output only. Refers to a variant in a ResourceBundle release.



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 501

class ResourceBundleDeploymentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Synchronization state of the resource bundle deployment.
  module SyncState
    # Unspecified state.
    SYNC_STATE_UNSPECIFIED = 0

    # Reconciling state.
    RECONCILING = 1

    # Stalled state.
    STALLED = 2

    # Synced state.
    SYNCED = 3

    # Pending state.
    PENDING = 4

    # Error state.
    ERROR = 5

    # Deletion pending state.
    DELETION_PENDING = 6

    # Deleting state.
    DELETING = 7

    # Deleted state.
    DELETED = 8
  end
end

#version::String (readonly)

Returns Output only. Refers to a version of the ResourceBundle release.

Returns:

  • (::String)

    Output only. Refers to a version of the ResourceBundle release.



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 501

class ResourceBundleDeploymentInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Synchronization state of the resource bundle deployment.
  module SyncState
    # Unspecified state.
    SYNC_STATE_UNSPECIFIED = 0

    # Reconciling state.
    RECONCILING = 1

    # Stalled state.
    STALLED = 2

    # Synced state.
    SYNCED = 3

    # Pending state.
    PENDING = 4

    # Error state.
    ERROR = 5

    # Deletion pending state.
    DELETION_PENDING = 6

    # Deleting state.
    DELETING = 7

    # Deleted state.
    DELETED = 8
  end
end