Class: Google::Cloud::ConfigDelivery::V1::RolloutStrategy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/configdelivery/v1/config_delivery.rb

Overview

RolloutStrategy defines different ways to rollout a resource bundle across a set of clusters.

Instance Attribute Summary collapse

Instance Attribute Details

#all_at_once::Google::Cloud::ConfigDelivery::V1::AllAtOnceStrategy

Returns AllAtOnceStrategy causes all clusters to be updated concurrently.

Note: The following fields are mutually exclusive: all_at_once, rolling. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ConfigDelivery::V1::AllAtOnceStrategy)

    AllAtOnceStrategy causes all clusters to be updated concurrently.

    Note: The following fields are mutually exclusive: all_at_once, rolling. If a field in that set is populated, all other fields in the set will automatically be cleared.



601
602
603
604
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 601

class RolloutStrategy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rolling::Google::Cloud::ConfigDelivery::V1::RollingStrategy

Returns RollingStrategy causes a specified number of clusters to be updated concurrently until all clusters are updated.

Note: The following fields are mutually exclusive: rolling, all_at_once. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ConfigDelivery::V1::RollingStrategy)

    RollingStrategy causes a specified number of clusters to be updated concurrently until all clusters are updated.

    Note: The following fields are mutually exclusive: rolling, all_at_once. If a field in that set is populated, all other fields in the set will automatically be cleared.



601
602
603
604
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 601

class RolloutStrategy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end