Class: Google::Cloud::ConfigDelivery::V1::RolloutStrategyInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/configdelivery/v1/config_delivery.rb

Overview

RolloutStrategyInfo represents the status of execution of different types of rollout strategies. Only the field corresponding to the rollout strategy specified at the rollout resource will be populated.

Instance Attribute Summary collapse

Instance Attribute Details

#all_at_once_strategy_info::Google::Cloud::ConfigDelivery::V1::AllAtOnceStrategyInfo

Returns AllAtOnceStrategyInfo represents the status of AllAtOnce rollout strategy execution.

Note: The following fields are mutually exclusive: all_at_once_strategy_info, rolling_strategy_info. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ConfigDelivery::V1::AllAtOnceStrategyInfo)

    AllAtOnceStrategyInfo represents the status of AllAtOnce rollout strategy execution.

    Note: The following fields are mutually exclusive: all_at_once_strategy_info, rolling_strategy_info. If a field in that set is populated, all other fields in the set will automatically be cleared.



621
622
623
624
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 621

class RolloutStrategyInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rolling_strategy_info::Google::Cloud::ConfigDelivery::V1::RollingStrategyInfo

Returns RollingStrategyInfo represents the status of Rolling rollout strategy execution.

Note: The following fields are mutually exclusive: rolling_strategy_info, all_at_once_strategy_info. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::ConfigDelivery::V1::RollingStrategyInfo)

    RollingStrategyInfo represents the status of Rolling rollout strategy execution.

    Note: The following fields are mutually exclusive: rolling_strategy_info, all_at_once_strategy_info. If a field in that set is populated, all other fields in the set will automatically be cleared.



621
622
623
624
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 621

class RolloutStrategyInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end