Class: Google::Cloud::ConfigDelivery::V1::UpdateVariantRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::UpdateVariantRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
Message for updating a Variant
Instance Attribute Summary collapse
-
#request_id ⇒ ::String
Optional.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
-
#variant ⇒ ::Google::Cloud::ConfigDelivery::V1::Variant
Required.
Instance Attribute Details
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
1011 1012 1013 1014 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1011 class UpdateVariantRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. Field mask is used to specify the fields to be overwritten in the Variant resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.
1011 1012 1013 1014 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1011 class UpdateVariantRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variant ⇒ ::Google::Cloud::ConfigDelivery::V1::Variant
Returns Required. The resource being updated.
1011 1012 1013 1014 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1011 class UpdateVariantRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |