Class: Google::Cloud::ConfigDelivery::V1::Variant

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/configdelivery/v1/config_delivery.rb

Overview

Variant represents the content of a ResourceBundle variant.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. [Output only] Create time stamp.

Returns:



895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 895

class Variant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. labels to represent any metadata associated with the variant.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. labels to represent any metadata associated with the variant.



895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 895

class Variant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. Name follows format of projects/{project}/locations/{location}/resourceBundles/{resource_bundle}/releases/{release}/variants/{variant}.

Returns:

  • (::String)

    Identifier. Name follows format of projects/{project}/locations/{location}/resourceBundles/{resource_bundle}/releases/{release}/variants/{variant}



895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 895

class Variant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#resources::Array<::String>

Returns Required. Input only. Unordered list. resources contain the kubernetes manifests (YAMLs) for this variant.

Returns:

  • (::Array<::String>)

    Required. Input only. Unordered list. resources contain the kubernetes manifests (YAMLs) for this variant.



895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 895

class Variant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. [Output only] Update time stamp.

Returns:



895
896
897
898
899
900
901
902
903
904
905
906
907
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 895

class Variant
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end