Class: Google::Cloud::ConfigDelivery::V1::DeleteReleaseRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::DeleteReleaseRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
Message for deleting a Release
Instance Attribute Summary collapse
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#force ⇒ ::Boolean
Returns Optional. If set to true, any variants of this release will also be deleted. (Otherwise, the request will only work if the release has no variants.).
1197 1198 1199 1200 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1197 class DeleteReleaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. Name of the resource.
1197 1198 1199 1200 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1197 class DeleteReleaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
1197 1198 1199 1200 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1197 class DeleteReleaseRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |