Module: Google::Cloud::ConfigDelivery::V1::DeletionPropagationPolicy
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
Deletion Propagation Policy determines what happens to the underlying
Kubernetes resources on a cluster when the FleetPackage managing
those resources no longer targets the cluster or is deleted.
Constant Summary collapse
- DELETION_PROPAGATION_POLICY_UNSPECIFIED =
Unspecified deletion propagation policy. Defaults to FOREGROUND.
0- FOREGROUND =
Foreground deletion propagation policy. Any resources synced to the cluster will be deleted.
1- ORPHAN =
Orphan deletion propagation policy. Any resources synced to the cluster will be abandoned.
2