Class: Google::Cloud::ConfigDelivery::V1::Fleet
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::Fleet
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
The fleet where the FleetPackage should be deployed.
Defined Under Namespace
Classes: LabelSelector
Instance Attribute Summary collapse
-
#project ⇒ ::String
Required.
-
#selector ⇒ ::Google::Cloud::ConfigDelivery::V1::Fleet::LabelSelector
Optional.
Instance Attribute Details
#project ⇒ ::String
Returns Required. The host project for the GKE fleet. Format is
projects/{project}.
545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 545 class Fleet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A label selector is a label query over a set of resources. An empty label # selector matches all objects. # @!attribute [rw] match_labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. match_labels is a map of \\{key,value} pairs. Each \\{key,value} # pair must match an existing label key and value exactly in order to # satisfy the match. class LabelSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MatchLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#selector ⇒ ::Google::Cloud::ConfigDelivery::V1::Fleet::LabelSelector
Returns Optional. selector allows targeting a subset of fleet members using their labels.
545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 545 class Fleet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A label selector is a label query over a set of resources. An empty label # selector matches all objects. # @!attribute [rw] match_labels # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. match_labels is a map of \\{key,value} pairs. Each \\{key,value} # pair must match an existing label key and value exactly in order to # satisfy the match. class LabelSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MatchLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |