Class: Google::Cloud::ConfigDelivery::V1::Fleet::LabelSelector
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::Fleet::LabelSelector
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
A label selector is a label query over a set of resources. An empty label selector matches all objects.
Defined Under Namespace
Classes: MatchLabelsEntry
Instance Attribute Summary collapse
Instance Attribute Details
#match_labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. match_labels is a map of {key,value} pairs. Each {key,value} pair must match an existing label key and value exactly in order to satisfy the match.
556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 556 class LabelSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class MatchLabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |