Class: Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleSelector
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleSelector
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
Information specifying the source of kubernetes configuration to deploy.
Instance Attribute Summary collapse
-
#cloud_build_repository ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository
Information specifying
CloudBuildRepository. -
#resource_bundle ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag
Information specifying
ResourceBundle.
Instance Attribute Details
#cloud_build_repository ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::CloudBuildRepository
Returns Information specifying CloudBuildRepository.
Note: The following fields are mutually exclusive: cloud_build_repository, resource_bundle. If a field in that set is populated, all other fields in the set will automatically be cleared.
265 266 267 268 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 265 class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_bundle ⇒ ::Google::Cloud::ConfigDelivery::V1::FleetPackage::ResourceBundleTag
Returns Information specifying ResourceBundle.
Note: The following fields are mutually exclusive: resource_bundle, cloud_build_repository. If a field in that set is populated, all other fields in the set will automatically be cleared.
265 266 267 268 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 265 class ResourceBundleSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |