Class: Google::Cloud::ConfigDelivery::V1::FleetPackage::VariantSelector
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::FleetPackage::VariantSelector
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
VariantSelector contains information for selecting a variant in
ResourceBundle to deploy to a target cluster.
Instance Attribute Summary collapse
-
#variant_name_template ⇒ ::String
Required.
Instance Attribute Details
#variant_name_template ⇒ ::String
Returns Required. variant_name_template is a template that can refer to variables containing cluster membership metadata such as location, name, and labels to generate the name of the variant for a target cluster. The variable syntax is similar to the unix shell variables.
Available variables are ${membership.name}, ${membership.location},
${membership.project} and ${membership.labels['label_name']}.
If you want to deploy a specific variant, say "default" to all the clusters, you can use "default" (string without any variables) as the variant_name_template.
337 338 339 340 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 337 class VariantSelector include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |