Class: Google::Cloud::ConfigDelivery::V1::ListVariantsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::ListVariantsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
Message for response to listing Variants
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#unreachable ⇒ ::Array<::String>
Unordered list.
-
#variants ⇒ ::Array<::Google::Cloud::ConfigDelivery::V1::Variant>
The list of Variants.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
941 942 943 944 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 941 class ListVariantsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unordered list. Locations that could not be reached.
941 942 943 944 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 941 class ListVariantsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variants ⇒ ::Array<::Google::Cloud::ConfigDelivery::V1::Variant>
Returns The list of Variants.
941 942 943 944 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 941 class ListVariantsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |