Class: Google::Cloud::ConfigDelivery::V1::ReleaseInfo
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::ReleaseInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
ReleaseInfo contains extra information about the ResourceBundle release
e.g., link to an artifact registry OCI image.
Defined Under Namespace
Classes: VariantOciImagePathsEntry
Instance Attribute Summary collapse
-
#oci_image_path ⇒ ::String
readonly
Output only.
-
#variant_oci_image_paths ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
Instance Attribute Details
#oci_image_path ⇒ ::String (readonly)
Returns Output only. path to the oci image the service uploads to on a Release
creation.
1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1050 class ReleaseInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VariantOciImagePathsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#variant_oci_image_paths ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. per-variant paths to the oci images the service uploads on package release creation.
1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1050 class ReleaseInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VariantOciImagePathsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |