Class: Google::Cloud::ConfigDelivery::V1::RollingStrategy
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::RollingStrategy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
RollingStrategy causes a specified number of clusters to be updated concurrently until all clusters are updated.
Instance Attribute Summary collapse
-
#max_concurrent ⇒ ::Integer
Optional.
Instance Attribute Details
#max_concurrent ⇒ ::Integer
Returns Optional. Maximum number of clusters to update the resource bundle on concurrently.
583 584 585 586 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 583 class RollingStrategy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |