Class: Google::Cloud::ConfigDelivery::V1::Rollout
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigDelivery::V1::Rollout
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/configdelivery/v1/config_delivery.rb
Overview
Rollout resource represents an instance of FleetPackage rollout operation
across a fleet. This is a system generated resource and will be read only for
end-users. It will be primarily used by the service to process the changes in
the FleetPackage and other changes in the environment.
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#deletion_propagation_policy ⇒ ::Google::Cloud::ConfigDelivery::V1::DeletionPropagationPolicy
Deletion propagation policy of the rollout.
-
#info ⇒ ::Google::Cloud::ConfigDelivery::V1::RolloutInfo
Current details of the rollout.
-
#name ⇒ ::String
Identifier.
-
#release ⇒ ::String
Reference to the
Releasebeing rolled out. -
#rollout_strategy ⇒ ::Google::Cloud::ConfigDelivery::V1::RolloutStrategy
Rollout strategy for rolling out
FleetPackageto clusters. -
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the rollout was created.
1325 1326 1327 1328 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1325 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deletion_propagation_policy ⇒ ::Google::Cloud::ConfigDelivery::V1::DeletionPropagationPolicy
Returns Deletion propagation policy of the rollout.
1325 1326 1327 1328 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1325 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#info ⇒ ::Google::Cloud::ConfigDelivery::V1::RolloutInfo
Returns Current details of the rollout.
1325 1326 1327 1328 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1325 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. Name of the Rollout. Format is
projects/{project}/locations/{location}/fleetPackages/{fleet_package}/rollouts/[a-z][a-z0-9\-]{0,62}.
1325 1326 1327 1328 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1325 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#release ⇒ ::String
Returns Reference to the Release being rolled out.
1325 1326 1327 1328 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1325 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rollout_strategy ⇒ ::Google::Cloud::ConfigDelivery::V1::RolloutStrategy
Returns Rollout strategy for rolling out FleetPackage to clusters.
1325 1326 1327 1328 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1325 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the rollout was most recently updated.
1325 1326 1327 1328 |
# File 'proto_docs/google/cloud/configdelivery/v1/config_delivery.rb', line 1325 class Rollout include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |